<?PHP
/**
 * Handles event category as used by MDPlausi.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Handles event category as used by MDPlausi.
 */
final class MDPlausiEventCategory {

    public int $earliest;
    public int $latest;
    public string $earliest_name = '';
    public string $latest_name = '';
    public string $earliest_time_name = '';
    public string $latest_time_name = '';

    /** @var 'actor'|'time' */
    public string $earliest_source;
    /** @var 'actor'|'time' */
    public string $latest_source;
    public int $earliest_event_type = 0;
    public int $latest_event_type = 0;

    /**
     * Formulates a plausi message part base on the earliest use of the category.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return string
     */
    public function formulateMessagePartForEarliest(MDTlLoader $tlLoader):string {

        if ($this->earliest_source === 'actor') {
            return ' (' . $tlLoader->tl("basis", "basis", "actor_short") . ': ' . $this->earliest_name . ' (* ' . $this->earliest_time_name . '))';
        }
        else {
            return ' (' . $this->earliest_name . ')';
        }

    }

    /**
     * Formulates a plausi message part base on the latest use of the category.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return string
     */
    public function formulateMessagePartForLatest(MDTlLoader $tlLoader):string {

        if ($this->latest_source === 'actor') {
            return ' (' . $tlLoader->tl("basis", "basis", "actor_short") . ': ' . $this->latest_name . ' (✝ ' . $this->latest_time_name . '))';
        }
        else {
            return ' (' . $this->latest_name . ')';
        }

    }

    /**
     * Constructor.
     *
     * @param int $default_earliest Default earliest time.
     * @param int $default_latest   Default latest time.
     *
     * @return void
     */
    public function __construct(int $default_earliest, int $default_latest) {

        $this->earliest = $default_earliest;
        $this->latest = $default_latest;

    }
}
