<?PHP
/**
 * Represents a section of object data that is checked by Puqi.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Represents a section of object data that is checked by Puqi.
 */
enum MDPuqiCheckSection implements JsonSerializable {

    case objectName;
    case objectType;
    case objectDescription;
    case objectMaterialTechnique;
    case objectMeasurements;
    case events;
    case tags;
    case collectionCount;
    case literatureCount;
    case hyperlinkCount;
    case documentCount;
    case linkedObjectCount;
    case seriesCount;
    case exhibitionCount;
    case translationCount;
    case transcriptCount;
    case objectHasReceptionCount;
    case objectIsReferenceCount;
    case markingCount;
    case imageCount;
    case publicInscription;
    case publicDetailedDescription;
    case publicComparableObjects;
    case metadataLicense;
    case imageMissing;
    case imageSizes;
    case imageLicenses;

    /**
     * Lists all available names.
     *
     * @return array<string>
     */
    public static function caseNames():array {

        $output = [];

        $cases = self::cases();
        foreach ($cases as $case) {
            $output[] = $case->name;
        }

        return $output;

    }

    /**
     * Provides the option to serialize as a string during json_encode().
     *
     * @return string
     */
    public function jsonSerialize():string {

        return $this->name;

    }
}
